@@ -476,7 +476,7 @@ mktime_utc (struct tm *tm)
 	tm->tm_isdst = -1;
 	tt = mktime (tm);
 	
-#if defined (G_OS_WIN32)
+#if defined (G_OS_WIN32) && !defined (__MINGW32__)
 	_get_timezone (&tz);
 	if (tm->tm_isdst > 0) {
 		int dst;
@@ -1670,9 +1670,11 @@ g_mime_utils_decode_8bit (const char *text, size_t len)
 		
 		while (inptr < inend) {
 			if (is_ascii (*inptr))
-				*outbuf++ = *inptr++;
+				*outbuf++ = *inptr;
 			else
 				*outbuf++ = '?';
+			
+			inptr++;
 		}
 		
 		*outbuf++ = '\0';
